// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation

public struct Activity: Codable, Identifiable {
    public let id: String
    public let practitioner: Practitioner
    public let location: Location?
    public let gestationWeek: String
    public let plannedTime: TimeRange?
    public let sortDate: Date
    public let status: Status
    public let title: String
    public let description: String?
    public let code: Code
    public let kind: String
    public let notes: [Note]
    public let observations: [Observation]

    public init(id: String,
                practitioner: Practitioner,
                location: Location,
                gestationWeek: String,
                plannedTime: TimeRange,
                sortDate: Date,
                status: Status,
                title: String,
                description: String,
                code: Code,
                kind: String,
                notes: [Note],
                observations: [Observation]) {
        self.id = id
        self.practitioner = practitioner
        self.location = location
        self.gestationWeek = gestationWeek
        self.plannedTime = plannedTime
        self.sortDate = sortDate
        self.status = status
        self.title = title
        self.description = description
        self.code = code
        self.kind = kind
        self.notes = notes
        self.observations = observations
    }
}
