// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation

/// Note that the properties of this class **DOES NOT** match the actual JSON structure,
/// but instead implements a custom parsing, because the backend can return two different
/// structures for this type.
public struct MenstrualCycle: Decodable {
    enum CodingKeys: CodingKey {
        case value
        case unit
        case start
        case end
        case calculated
    }

    public let inDays: BodyMeasureValue?
    public let fromDates: MenstrualCycleFromDates?

    public init(from decoder: Decoder) throws {
        let container = try decoder.container(keyedBy: CodingKeys.self)

        if container.contains(.start) || container.contains(.end) {
            let start = try container.decodeIfPresent(Date.self, forKey: .start)
            let end = try container.decodeIfPresent(Date.self, forKey: .end)
            let calculated = try container.decodeIfPresent(BodyMeasureValue.self, forKey: .calculated)
            fromDates = MenstrualCycleFromDates(start: start, end: end, calculated: calculated)
            inDays = nil
        } else if let value = try container.decodeIfPresent(Double.self, forKey: .value),
                  let unit = try container.decodeIfPresent(String.self, forKey: .unit) {
            fromDates = nil
            inDays = BodyMeasureValue(value: value, unit: unit)
        } else {
            fromDates = nil
            inDays = nil
        }
    }

    public init(inDays: BodyMeasureValue?, fromDates: MenstrualCycleFromDates?) {
        self.inDays = inDays
        self.fromDates = fromDates
    }
}

public struct MenstrualCycleFromDates: Decodable {
    public let start: Date?
    public let end: Date?
    public let calculated: BodyMeasureValue?

    public init(start: Date?, end: Date?, calculated: BodyMeasureValue?) {
        self.start = start
        self.end = end
        self.calculated = calculated
    }
}
