// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

public struct ScreeningsSection: Decodable {
    public let hepatitisB: ScreeningWithDateSection?
    public let hiv: ScreeningWithDateSection?
    public let syphilis: ScreeningWithDateSection?
    public let chlamydia: ScreeningWithDateSection?
    public let gonorrhea: ScreeningWithDateSection?
    public let streptococcusGroupB: ScreeningWithDateSection?
    public let hemoglobinopathy: ScreeningWithDateSection?
    public let vitaminDConsumption: DateValueUnitScreeningSection?
    public let maternalRhDAntibody: MaternalRhDAntibodyScreeningSection?
    public let fetalRhDAntibody: FetalRhDAntibodyScreeningSection?
    public let diabetesWeek18To20: DateValueUnitScreeningSection?
    public let diabetesWeek28To30: DateValueUnitScreeningSection?
    public let diabetesGlycosuria: DateValueUnitScreeningSection?
    public let antiDImmunoglobulinGiven: ScreeningYesNoWithDateSection?
    public let mrsaSwap: ScreeningYesNoWithDateSection?

    public init(
        hepatitisB: ScreeningWithDateSection?,
        hiv: ScreeningWithDateSection?,
        syphilis: ScreeningWithDateSection?,
        chlamydia: ScreeningWithDateSection?,
        gonorrhea: ScreeningWithDateSection?,
        streptococcusGroupB: ScreeningWithDateSection?,
        hemoglobinopathy: ScreeningWithDateSection?,
        vitaminDConsumption: DateValueUnitScreeningSection?,
        maternalRhDAntibody: MaternalRhDAntibodyScreeningSection?,
        fetalRhDAntibody: FetalRhDAntibodyScreeningSection?,
        diabetesWeek18To20: DateValueUnitScreeningSection?,
        diabetesWeek28To30: DateValueUnitScreeningSection?,
        diabetesGlycosuria: DateValueUnitScreeningSection?,
        antiDImmunoglobulinGiven: ScreeningYesNoWithDateSection?,
        mrsaSwap: ScreeningYesNoWithDateSection?) {
        self.hepatitisB = hepatitisB
        self.hiv = hiv
        self.syphilis = syphilis
        self.chlamydia = chlamydia
        self.gonorrhea = gonorrhea
        self.streptococcusGroupB = streptococcusGroupB
        self.hemoglobinopathy = hemoglobinopathy
        self.vitaminDConsumption = vitaminDConsumption
        self.maternalRhDAntibody = maternalRhDAntibody
        self.fetalRhDAntibody = fetalRhDAntibody
        self.diabetesWeek18To20 = diabetesWeek18To20
        self.diabetesWeek28To30 = diabetesWeek28To30
        self.diabetesGlycosuria = diabetesGlycosuria
        self.antiDImmunoglobulinGiven = antiDImmunoglobulinGiven
        self.mrsaSwap = mrsaSwap
    }
}
