// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import os.log

/// Multi logger class to log for multiple loggers at once
public final class MultiLogger : LoggerProtocol {
    /// Loggers to invoke
    public var loggers: [LoggerProtocol] = []

    /// Initializes multiple loggers
    public init(loggers: [LoggerProtocol]) {
        self.loggers = loggers
    }

    public func log(_ message: String, at level: LogLevel, file: String, function: String, line: UInt, category: String?) {
        invokeLoggers { (logger: LoggerProtocol) in
            logger.log(message, at: level, file: file, function: function, line: line, category: category)
        }
    }

    private func invokeLoggers(function: @escaping (LoggerProtocol) -> Void) {
        for logger: LoggerProtocol in loggers {
            function(logger)
        }
    }
}
