// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import UIKit
import MaternityData

protocol ObservationTableMeasurementType {
    var rawValue: String { get }
    var title: String { get }
}

private let dateFormatter: DateFormatter = {
    let df = DateFormatter()
    df.dateStyle = .short
    df.timeStyle = .none
    return df
}()

extension ObservationTableMeasurementType {
    static func valueColumn<T: ObservationTableDataTableCellGenerator>(activity: ObservationTableActivity, width: CGFloat, generator: T) -> [DataTableCell] {
        var valueColumnForActivity: [DataTableCell] = []
        valueColumnForActivity.append(
            DataTableCell(
                id: activity.activityId,
                value: dateFormatter.string(from: activity.date),
                type: .boldText,
                fixedWidth: width
            )
        )

        let measurementTypes = T.MeasurementType.allCases
        for measurementType in measurementTypes {
            valueColumnForActivity.append(
                generator.dataTableCell(for: measurementType, activityId: activity.activityId, valueWidth: width)
            )
        }
        return valueColumnForActivity
    }
}
