// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import UIKit
import CMSServices
import MaternityServices
import MaternityData
import ErrorData
import CMSData
import Combine

final class ObservationTableServiceImpl: ObservationTableService {
    @DI private var dictionaryService: DictionaryService
    @DI private var observationService: ObservationService

    func fetchScanTable(titleWidth: CGFloat, valueWidth: CGFloat) -> AnyPublisher<DataTableColumnSet, ServiceError> {
        dictionaryService.fetchDictionaryWithEmptyFallback()
            .setFailureType(to: ServiceError.self)
            .flatMap({ (dictionary: CMSDictionary) -> AnyPublisher<DataTableColumnSet, ServiceError> in
                self.observationService.fetchObservationsTableScan()
                    .map({ (table: ObservationTableScan) -> DataTableColumnSet in
                        table.toDataTableColumnSet(dictionary: dictionary, titleWidth: titleWidth, valueWidth: valueWidth)
                    })
                    .eraseToAnyPublisher()
            })
            .eraseToAnyPublisher()
    }

    func fetchClinicalTable(titleWidth: CGFloat, valueWidth: CGFloat) -> AnyPublisher<DataTableClinicalResult, ServiceError> {
        dictionaryService.fetchDictionaryWithEmptyFallback()
            .setFailureType(to: ServiceError.self)
            .flatMap({ (dictionary: CMSDictionary) -> AnyPublisher<DataTableClinicalResult, ServiceError> in
                self.observationService.fetchObservationsTableClinical()
                    .map({ (table: ObservationTableClinical) -> DataTableClinicalResult in
                        let columnSet = table.toDataTableColumnSet(dictionary: dictionary, titleWidth: titleWidth, valueWidth: valueWidth)
                        #warning("pubisMeasurements X-values are randomized, waiting for API update")
                        return DataTableClinicalResult(
                            tableColumnSet: columnSet,
                            pubisMeasurements: table.mother?.rows?.compactMap({ row in
                                guard let measurement = row.pubismeasurement else {
                                    return nil
                                }
                                return PubisMeasurementChartEntry(
                                    maternityWeek: Double.random(in: 0...40),
                                    measurement: measurement
                                )
                            }) ?? []
                        )

                    })
                    .eraseToAnyPublisher()
            })
            .eraseToAnyPublisher()
    }
}
