// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import CMSServices
import Combine
import ErrorData
import MaternityData
import MaternityServices

final class OverallAssessmentServiceImpl: OverallAssessmentService {
    @DI private var userContext: UserContextProtocol
    @DI private var dictionaryService: DictionaryService
    
    func fetchOverallAssessments() -> AnyPublisher<[KeyValueModel], ServiceError> {
        guard let overallAssessmentSection = userContext.userDataCard?.overallAssessmentSection else {
            return Just([])
                .mapToServiceError()
                .eraseToAnyPublisher()
        }
        
        return dictionaryService.fetchDictionaryWithEmptyFallback()
            .map { dictionary -> [KeyValueModel] in
                [
                    KeyValueModel.dictionaryModel(
                        title: R.string.localizable.journal_section_overall_assessment_prenatal_assessment(),
                        primaryValue: overallAssessmentSection.prenatalCareAssessment?.assessment,
                        dictionary: dictionary
                    ),
                    
                    KeyValueModel.dictionaryModel(
                        title: R.string.localizable.journal_section_overall_assessment_prenatal_carelevel(),
                        primaryValue: overallAssessmentSection.prenatalCareAssessment?.careLevel?.description,
                        dictionary: dictionary
                    ),
                    
                    KeyValueModel.dictionaryModel(
                        title: R.string.localizable.journal_section_overall_assessment_prenatal_comments(),
                        primaryValue: overallAssessmentSection.prenatalCareAssessment?.comment
                    ),
                    
                    KeyValueModel.dictionaryModel(
                        title: R.string.localizable.journal_section_overall_assessment_obstetric_required(),
                        primaryValue: overallAssessmentSection.obstetricAssessment?.required.description,
                        
                        dictionary: dictionary),
                    
                    KeyValueModel.dictionaryModel(
                        title: R.string.localizable.journal_section_overall_assessment_obstetrics_reason(),
                        primaryValue: overallAssessmentSection.obstetricAssessment?.reason
                    ),
                    
                    KeyValueModel.dictionaryModel(
                        title: R.string.localizable.journal_section_overall_assessment_social_services_perinatal_care_required(),
                        primaryValue: overallAssessmentSection.socialServicesPerinatalCareAssessment?.required.description,
                        dictionary: dictionary
                    ),
                    
                    KeyValueModel.dictionaryModel(
                        title: R.string.localizable.journal_section_overall_assessment_social_services_perinatal_care_reason(),
                        primaryValue: overallAssessmentSection.socialServicesPerinatalCareAssessment?.reason
                    )
                ]
            }
            .mapToServiceError()
            .eraseToAnyPublisher()
    }
}
