// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct PINTitleView: View {

    let pinCodeLength: UInt
    let isBiometricLoginAvailable: Bool
    let title: String
    let infoText: String
    let wrongCodeText: String

    @Binding var pinCode: String
    @Binding var isLoading: Bool
    @Binding var wrongCode: Bool
    @Binding var biometricLoginWasActivated: Bool
    @Binding var shouldResetWrongPinCodeState: Bool

    var body: some View {
        VStack {
            VStack {
                Text(title)
                    .applyTextStyle(fontStyle: .hero)
                    .padding()
                Text(infoText)
                    .applyTextStyle(fontStyle: .body)
            }
            .padding()
            Spacer()
            PINCodeView(
                pinCodeLength: pinCodeLength,
                isBiometricLoginAvailable: isBiometricLoginAvailable,
                pinCode: $pinCode,
                isLoading: $isLoading,
                wrongCode: $wrongCode,
                biometricLoginWasActivated: $biometricLoginWasActivated,
                shouldResetWrongPinCodeState: $shouldResetWrongPinCodeState
            )
            .frame(maxHeight: Metrics.Sizes.pinCodeCircleSize, alignment: .center)
            .padding()

            Text(wrongCodeText)
                .applyTextStyle(fontStyle: .info, textColor: R.color.errorRed.color())
                .opacity(wrongCode ? 1.0 : 0.0)
            Spacer()
        }
    }
}

struct PINTitleView_Previews: PreviewProvider {
    static var previews: some View {
        PINTitleView(
            pinCodeLength: 4,
            isBiometricLoginAvailable: true,
            title: "Title",
            infoText: "Info text text text",
            wrongCodeText: "Wrong code!",
            pinCode: .constant(""),
            isLoading: .constant(false),
            wrongCode: .constant(false),
            biometricLoginWasActivated: .constant(false),
            shouldResetWrongPinCodeState: .constant(false)
        )
    }
}
