// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import MaternityData
import CMSData

struct AppointmentDetailContentPickerView: View {
    @State private var selectedPickerValue: PickerValue = .description
    let activity: Activity
    let dictionary: CMSDictionary

    var body: some View {
        VStack(alignment: .leading) {
            Picker("", selection: $selectedPickerValue) {
                ForEach(PickerValue.allCases) { value in
                    Text(value.title)
                        .tag(value)
                }
            }
            .pickerStyle(SegmentedPickerStyle())
            .padding(.bottom)
            switch selectedPickerValue {
            case .description:
                AppointmentDetailsDescriptionView(description: activity.description)
            case .measurements:
                AppointmentDetailMeasurementsView(
                    allFetusesObservations: activity.observations.fetusesObservations,
                    motherObservations: activity.observations.motherObservations,
                    dictionary: dictionary
                )
            case .journal:
                AppointmentDetailJournalNotesView(notes: activity.notes)
            }
        }
    }
}

private enum PickerValue: Int, CaseIterable, Identifiable {
    case description
    case measurements
    case journal

    var id: Int {
        rawValue
    }

    var title: String {
        switch self {
        case .description:
            return R.string.localizable.appointment_details_description()
        case .measurements:
            return R.string.localizable.appointment_details_measurements()
        case .journal:
            return R.string.localizable.appointment_details_journalnotes()
        }
    }
}

#if DEBUG
struct AppointmentDetailContentPickerView_Previews: PreviewProvider {
    static var previews: some View {
        AppointmentDetailContentPickerView(
            activity: loadPreviewCarePlans()
                .flatMap { $0.activities }
                .first!,
            dictionary: CMSDictionary.empty()
        )
        .padding()
    }
}
#endif
