// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import MaternityData

struct ActivityCardView: View {    
    let activity: Activity

    var body: some View {
        BasicCardView {
            HStack {
                VStack(alignment: .leading) {
                    VStack(alignment: .leading) {
                        Text(activity.title)
                            .applyTextStyle(fontStyle: .h3)
                        
                        if let from = activity.plannedTime?.from {
                            Text(AppointmentsView.dateFormatter.string(from: from))
                                .applyTextStyle(fontStyle: .h5)
                        } else {
                            Text(R.string.localizable.appointment_details_estimated_date_value(activity.gestationWeek))
                                .applyTextStyle(fontStyle: .h5)
                        }
                    }
                    .padding(.bottom, 4)

                    if let from = activity.plannedTime?.from, let to = activity.plannedTime?.to {
                        KeyValueInfoView(key: R.string.localizable.appointment_time_label(), value: AppointmentsView.timeFormatter.string(from: from)
                                            .appending(" - ")
                                            .appending(AppointmentsView.timeFormatter.string(from: to)))
                    }

                    if let location = activity.location {
                        KeyValueInfoView(key: R.string.localizable.appointment_location_label(), value: location.organizationName)
                    }
                    KeyValueInfoView(key: R.string.localizable.appointment_at_label(), value: activity.practitioner.fullName)
                }

                Spacer()

                VStack(alignment: .trailing) {
                    if !activity.notes.isEmpty || !activity.observations.isEmpty {
                        CircleCardView {
                            Image(R.image.journal_info.name)
                                .renderingMode(.original)
                                .frame(size: 18)
                        }
                        .frame(size: 32)
                    }
                    Spacer()
                    ChevronRightView()
                }
            }
            .padding()
        }
    }
}

#if DEBUG
struct ActivityCardView_Previews: PreviewProvider {
    static var previews: some View {
        ScrollView {
            VStack {
                Spacer()
                ActivityCardView(activity: loadPreviewCarePlans()
                                    .flatMap { $0.activities }
                                    .first!)
                ActivityCardView(activity: loadPreviewCarePlans()
                                    .flatMap { $0.activities }
                                    .last!)
                Spacer()
            }
        }
        .background(R.color.viewBackground.color())
        .environment(\.colorScheme, .dark)

        ScrollView {
            VStack {
                Spacer()
                ActivityCardView(activity: loadPreviewCarePlans()
                                    .flatMap { $0.activities }
                                    .first!)
                ActivityCardView(activity: loadPreviewCarePlans()
                                    .flatMap { $0.activities }
                                    .last!)
                Spacer()
            }
        }
        .background(R.color.viewBackground.color())
        .environment(\.colorScheme, .light)
    }
}
#endif
