// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import Charts

struct JournalMeasurementsView: View, ScreenTrackable {
    @ObservedObject var viewModel: ViewModel

    init(viewModel: ViewModel = ViewModel()) {
        self.viewModel = viewModel
    }

    var body: some View {
        DataLoadingView(
            state: viewModel.state,
            retryAction: viewModel.fetchData,
            content: {
                ScrollView(.vertical) {
                    VStack(spacing: 24) {
                        CircleImageHeaderView(
                            title: R.string.localizable.journal_section_measurements_title(),
                            text: R.string.localizable.journal_section_measurements_description(),
                            imageUrl: nil,
                            image: Image(R.image.measurements.name).resizable()
                        )
                        .padding([.horizontal, .top])
                        HStack {
                            Text(R.string.localizable.journal_section_measurements_graph_title())
                                .applyTextStyle(fontStyle: .h2)
                            Spacer()
                        }
                        .padding(.horizontal)
                        JournalMeasurementChartsCard(
                            chartValues: viewModel.chartValues,
                            chartArea: viewModel.chartArea,
                            chartXUnit: viewModel.chartXUnit,
                            chartYUnit: viewModel.chartYUnit
                        )
                        JournalMeasurementsTableCard(
                            valueColumns: viewModel.valueColumns,
                            titleColumn: viewModel.titleColumn
                        )
                        JournalKeyValueStackView(
                            title: R.string.localizable.journal_section_measurements_weight_before_maternity_title(),
                            data: viewModel.bodyMeasureValues
                        )
                        .padding()
                    }
                }
            })
            .navigationBarTitle(Text(R.string.localizable.journal_section_measurements_title()), displayMode: .inline)
            .onAppear(perform: {
                trackScreenAppearing()
                viewModel.fetchData()
            })
            .onDisappear(perform: trackScreenDisappearing)
    }
}

struct JournalMeasurementsView_Previews: PreviewProvider {
    static var previews: some View {
        JournalMeasurementsView(
            viewModel: JournalMeasurementsView.PreviewViewModel()
        )
        .background(R.color.viewBackground.color())
    }
}
