// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import MaternityData

struct JournalMeasurementsTableCard: View {

    let valueColumns: [[DataTableCell]]
    let titleColumn: [DataTableCell]

    var scrollProgress: Double {
        max(
            0,
            Double(-scrollOffset.x) / (Double(scrollContentSize.width) - Double(scrollViewSize.width))
        )
    }
    @State private var scrollOffset: CGPoint = .zero
    @State private var scrollContentSize: CGSize = .zero
    @State private var scrollViewSize: CGSize = .zero
    @State private var showNotImplementedAlert: Bool = false

    var body: some View {
        BottomContainerCardView {
            VStack(spacing: 0) {
                VStack(alignment: .leading, spacing: 8) {
                    Text(R.string.localizable.journal_section_measurements_table_title())
                        .applyTextStyle(fontStyle: .h2)
                    Text(R.string.localizable.journal_section_measurements_table_description())
                        .applyTextStyle(fontStyle: .body)
                        .fixedSize(horizontal: false, vertical: true)
                    HStack {
                        Spacer()
                        Button(
                            action: {
                                #warning("Bring table up in fullscreen on landscape orientation")
                                showNotImplementedAlert = true
                            },
                            label: {
                                HStack {
                                    Text(R.string.localizable.journal_section_measurements_table_rotate())
                                        .applyTextStyle(fontStyle: .h5, textColor: R.color.primary.color())
                                    Image(R.image.rotate.name)
                                        .renderingMode(.original)
                                }
                            })
                    }
                }
                .padding([.horizontal, .bottom ])
                ProgressBar(progress: scrollProgress)
                ScrollableDataTable(
                    valueColumns: valueColumns,
                    titleColumnRows: titleColumn,
                    scrollOffset: $scrollOffset,
                    scrollContentSize: $scrollContentSize,
                    scrollViewSize: $scrollViewSize
                )
            }
        }
        .notImplementedAlert(isPresented: $showNotImplementedAlert)
    }
}

struct JournalMeasurementsTableCard_Previews: PreviewProvider {
    static var previews: some View {
        ScrollView {
            JournalMeasurementsTableCard(
                valueColumns: ScrollableDataTable.previewColumns(),
                titleColumn: ScrollableDataTable.previewTitleColumn()
            )
        }
    }
}
