// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import LexiconData
import LexiconServices
import SwiftUI

extension LexiconListView {
    final class ViewModel: ObservableObject {
        @DI private var lexiconService: LexiconService
        @Published var lexicons: [Lexicon] = []

        private let category: LexiconData.Category
        private var cancelBag: CancelBag = CancelBag()

        init(category: LexiconData.Category) {
            self.category = category
        }

        func fetchData() {
            lexiconService.fetchLexicons(categories: [category], searchQuery: nil)
                .receiveOnMain()
                .sink(receiveCompletion: { completion in
                    print(completion)
                }, receiveValue: { lexicons in
                    self.lexicons = lexicons
                })
                .store(in: &cancelBag)
        }
    }
}
