// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import LexiconData

struct KnowledgeViewCategoriesSection: View {
    var categories: [LexiconData.Category]

    var body: some View {
        KnowledgeViewListSection(title: R.string.localizable.subjects_title()) {
            VStack(spacing: 16) {
                ForEach(categories) { category in
                    NavigationLink(
                        destination: LexiconListView(category: category),
                        label: {
                            LexiconCategoryCard(category: category)
                        })
                        .accessibility(identifier: category.name)
                }
            }
            .padding()
        }
    }
}

struct KnowledgeViewCategoriesSection_Previews: PreviewProvider {
    static var previews: some View {
        KnowledgeViewCategoriesSection(categories: [
            LexiconData.Category(
                id: "text",
                imageUrl: URL(string: "https://via.placeholder.com/150")!,
                name: "Text",
                description: "Some description",
                count: 22
            )
        ])
    }
}
