// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import MaternityData

struct OverviewView: View, ScreenTrackable {
    @ObservedObject private var viewModel = ViewModel()

    var body: some View {
        NavigationView {
            ScrollView {
                if App.buildConfiguration == .debug {
                    DataLoadingView(
                        state: viewModel.state,
                        animateStateChanges: true,
                        retryAction: {},
                        content: {
                            CompatibleVStack(alignment: .leading) {
                                Section(header: Text(R.string.localizable.overview_your_continuity_of_maternity()).applyTextStyle(fontStyle: .h4)) {
                                    if let weekProgress = viewModel.weekProgress,
                                       let dueDate = viewModel.dueDate,
                                       let months = viewModel.months,
                                       let trimester = viewModel.trimester {
                                        OverviewContinuityOfMaternityCard(
                                            maternityWeekProgress: weekProgress,
                                            dueDate: dueDate,
                                            months: months,
                                            trimester: trimester
                                        )
                                    } else {
                                        EmptyStateView(
                                            title: R.string.localizable.overview_empty_state_title(),
                                            text: R.string.localizable.overview_empty_state_text()
                                        )
                                    }
                                }
                                Section(header: Text(R.string.localizable.overview_next_appointment()).applyTextStyle(fontStyle: .h4)) {
                                }
                                Section(header: Text(R.string.localizable.overview_relevant_right_now()).applyTextStyle(fontStyle: .h4)) {
                                }
                            }
                            .padding()
                        })
                } else {
                    EmptyStateView.notImplemented()
                }
            }
            .navigationBarTitle(viewModel.userName)
            .onAppear(perform: trackScreenAppearing)
            .onDisappear(perform: trackScreenDisappearing)
        }
        .navigationViewStyle(StackNavigationViewStyle())
    }
}

struct OverviewView_Previews: PreviewProvider {
    static var previews: some View {
        OverviewView()
    }
}
