// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import MaternityServices
import MaternityData

extension OverviewView {
    final class ViewModel: ObservableObject {
        private var cancelBag = CancelBag()
        @DI private var userContext: UserContextProtocol

        @Published var state: DataLoadingState = .initial

        private var expectedDeliverySection: ExpectedDateOfDeliverySection? {
            userContext.userDataCard?.expectedDateOfDeliverySection
        }

        var userName: String {
            userContext.userDataCard?.recordTarget.name.fullName
                ?? R.string.localizable.common_unknown()
        }

        var weekProgress: String {
            expectedDeliverySection?.gestationAge
                ?? R.string.localizable.common_unknown()
        }

        var trimester: Int? {
            expectedDeliverySection?.trimester
        }

        var months: Double? {
            expectedDeliverySection?.monthsIntoPregnancy
        }

        var dueDate: Date? {
            expectedDeliverySection?.activeDueDate
        }

        init() {
            state = .data
        }
    }
}
