// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import MaternityData

struct OverviewContinuityOfMaternityCard: View {

    let maternityWeekProgress: String
    let dueDate: Date
    let months: Double
    let trimester: Int

    private let cornerRadiusConfig = CornerRadiusConfig(
        topLeft: Metrics.Sizes.cardCornerRadius,
        topRight: 80,
        bottomLeft: Metrics.Sizes.cardCornerRadius,
        bottomRight: Metrics.Sizes.cardCornerRadius
    )

    private static var dateFormatter: DateFormatter = {
        let dateFormatter = DateFormatter()
        dateFormatter.dateStyle = .medium
        dateFormatter.timeStyle = .none
        return dateFormatter
    }()

    var body: some View {
        BasicCardView(cornerRadiusConfig: cornerRadiusConfig) {
            HStack {
                VStack(alignment: .leading, spacing: 10) {
                    Text(R.string.localizable.overview_weeks_progress(maternityWeekProgress))
                        .applyTextStyle(fontStyle: .h4)
                        .padding(.top)
                    OverviewContinuityOfMaternityValue(
                        title: R.string.localizable.overview_due_date(),
                        value: OverviewContinuityOfMaternityCard.dateFormatter.string(from: dueDate)
                    )
                    OverviewContinuityOfMaternityValue(
                        title: R.string.localizable.overview_you_are_in(),
                        value: R.string.localizable.overview_th_month(Int(floor(months)))
                    )
                    OverviewContinuityOfMaternityValue(
                        title: R.string.localizable.overview_you_are_in_maternity(),
                        value: R.string.localizable.overview_th_trimester(trimester)
                    )
                }
                Spacer()
                VStack {
                    InnerShadowCircleView {
                        Image(R.image.empty_state.name)
                            .resizable()
                    }
                    .frame(size: 160)
                }
            }
            .padding()
        }
    }
}

struct OverviewContinuityOfMaternityCard_Previews: PreviewProvider {
    static var previews: some View {
        OverviewContinuityOfMaternityCard(
            maternityWeekProgress: "10+5",
            dueDate: Date(),
            months: 5,
            trimester: 2
        )
        .padding()
    }
}
