// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct OnboardingConsentView: View, ScreenTrackable {
    @Environment(\.presentationMode) var presentationMode
    @ObservedObject var viewModel = OnboardingConsentView.ViewModel()

    var body: some View {
        NavigationView {
            VStack {
                ScrollView {
                    VStack(alignment: .leading, spacing: 10) {
                        Text(R.string.localizable.agreement_header1())
                            .applyTextStyle(fontStyle: .h2)
                        Text(R.string.localizable.agreement_text1())
                            .applyTextStyle(fontStyle: .body)
                        Text(R.string.localizable.agreement_header2())
                            .applyTextStyle(fontStyle: .h2)
                        Text(R.string.localizable.agreement_text2())
                            .applyTextStyle(fontStyle: .body)
                    }
                    .padding()
                }
                SUIButton<PrimaryButton>(R.string.localizable.agreement_button_text()) {
                    viewModel.performOpenIDConnectLogin()
                }
                .frame(height: Metrics.Sizes.buttonHeight)
                .padding()
                .accessibility(identifier: "consent_accept")
                .alert(isPresented: $viewModel.oidcLoginFailed, content: {
                    Alert(
                        title: Text(R.string.localizable.common_alert_title_error()),
                        message: Text(R.string.localizable.common_alert_message_generic()),
                        dismissButton: .default(Text(R.string.localizable.common_ok()))
                    )
                })

            }
            .modifier(InlineNavigationBarTitleModalModifier())
            .navigationBarItems(trailing:
                                    Button(action: {
                                        presentationMode.wrappedValue.dismiss()
                                    }, label: {
                                        Image(R.image.close.name)
                                    })
            )
            .onAppear(perform: trackScreenAppearing)
            .onDisappear(perform: trackScreenDisappearing)
        }
        .navigationViewStyle(StackNavigationViewStyle())
    }
}

struct OnboardingConsentView_Previews: PreviewProvider {
    static var previews: some View {
        OnboardingConsentView()
    }
}

/// iOS 13 crashes when setting the displayMode in this specific case (normally it is okay, though ...)
private struct InlineNavigationBarTitleModalModifier: ViewModifier {
    func body(content: Content) -> some View {
        let title = R.string.localizable.agreement_title()
        let result: AnyView
        if #available(iOS 14, *) {
            result = AnyView(content.navigationBarTitle(Text(title), displayMode: .inline))
        } else {
            result = AnyView(content.navigationBarTitle(title))
        }
        return result
    }
}
