// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import TIM

struct OnboardingView: View, ScreenTrackable {
    @DI private var logger: Logger

    @ObservedObject var viewModel = OnboardingView.ViewModel()

    var body: some View {
        VStack {
            GeometryReader { geo in
                SUIScrollView(
                    currentPage: $viewModel.currentPage,
                    isPaged: true,
                    bounces: false,
                    showIndicators: false) {
                    HStack(spacing: 0) {
                        ForEach(viewModel.steps.indices) { index in
                            OnboardingStepView(viewModel: viewModel.steps[index])
                                .tag(index)
                                .frame(
                                    width: geo.size.width,
                                    height: geo.size.height
                                )
                        }
                    }
                }
            }
            Spacer()
            PageIndicators(numberOfPages: viewModel.steps.count, currentIndex: viewModel.currentPage)
            Spacer(minLength: 20)
            VStack {
                SUIButton<PrimaryButton>(R.string.localizable.onboarding_login_nemid_button()) {
                    viewModel.presentConsent = true
                }
                .frame(height: Metrics.Sizes.buttonHeight)
                .accessibility(identifier: "login_nemid")
                SUIButton<SecondaryButton>(R.string.localizable.onboarding_login_get_started_button()) {
                    viewModel.skipLogin()
                }
                .frame(height: Metrics.Sizes.buttonHeight)
                .accessibility(identifier: "login_without_nemid")
            }
            .padding()
        }
        .onAppear(perform: trackScreenAppearing)
        .onDisappear(perform: trackScreenDisappearing)
        .sheet(isPresented: $viewModel.presentConsent, content: {
            OnboardingConsentView()
        })
    }
}

struct OnboardingView_Previews: PreviewProvider {
    static var previews: some View {
        Group {
            OnboardingView()
                .previewDevice("iPhone 12 Pro")

            OnboardingView()
                .previewDevice("iPhone SE")
        }
    }
}
