// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import LocalAuthentication

struct ChoosePinCodeView: View, ScreenTrackable {
    @ObservedObject var viewModel: ViewModel

    init(userId: String) {
        self.viewModel = ViewModel(userId: userId)
    }

    var body: some View {
        LoginBackgroundView()
            .overlay(
                VStack {
                    PINTitleView(
                        pinCodeLength: viewModel.pinCodeLength,
                        isBiometricLoginAvailable: false,
                        title: R.string.localizable.login_select_pin_title(),
                        infoText: R.string.localizable.login_select_pin_text(),
                        wrongCodeText: "",
                        pinCode: $viewModel.pinCode,
                        isLoading: $viewModel.isLoading,
                        wrongCode: .constant(false),
                        biometricLoginWasActivated: .constant(false),
                        shouldResetWrongPinCodeState: .constant(false)
                    )
                }
                .onAppear(perform: trackScreenAppearing)
                .onDisappear(perform: trackScreenDisappearing)
            )
        // Multiple alerts on same view...
        VStack {}
            .alert(isPresented: $viewModel.failedToSetPinCode, content: {
                Alert(
                    title: Text(R.string.localizable.common_alert_title_error()),
                    message: Text(R.string.localizable.login_error_refresh_token_expired()),
                    dismissButton: .default(Text(R.string.localizable.common_retry()), action: {
                        viewModel.resetToOnboarding()
                    })
                )
            })
        VStack {}
            .alert(isPresented: $viewModel.askToEnableTouchID, content: {
                Alert(
                    title: Text(viewModel.bioName),
                    message: Text(R.string.localizable.ios_alert_login_message_biometric(viewModel.bioName)),
                    primaryButton: .default(Text(R.string.localizable.ios_alert_login_cta_use(viewModel.bioName)), action: {
                        viewModel.enableBio()
                    }),
                    secondaryButton:
                        .cancel(Text(R.string.localizable.ios_alert_login_cta_dont_use()), action: {
                            viewModel.finishRegisterFlow()
                        })
                )
            })
        VStack { }
            .alert(isPresented: $viewModel.failedToLoadInitialData, content: {
                Alert(
                    title: Text(R.string.localizable.login_loading_data_failed_alert_title()),
                    message: Text(R.string.localizable.login_loading_data_failed_alert_description()),
                    dismissButton: .default(Text(R.string.localizable.common_ok()))
                )
            })
    }
}

struct ChoosePinCodeView_Previews: PreviewProvider {
    static var previews: some View {
        ChoosePinCodeView(userId: "<userId>")
    }
}
