// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import UIKit
import Charts

final class MeasurementsLineChartYAxisRenderer: YAxisRenderer {
    override func renderGridLines(context: CGContext) {
        guard let
            yAxis = self.axis as? YAxis, yAxis.isEnabled && yAxis.drawGridLinesEnabled
            else { return }

        let positions = transformedPositions()
        // Skip first line, since it is on top of the axis line
        for i in positions.indices.suffix(from: 1) {
            let point = positions[i]
            context.saveGState()
            context.setLineWidth(1)
            context.setStrokeColor(R.color.measurementsChartLines()!.cgColor)
            if !MeasurementsLineChartUtil.isPositionIndexSolidLine(i) {
                context.setLineDash(phase: 0, lengths: [6, 3])
            }
            self.drawGridLine(context: context, position: point)
            context.restoreGState()
        }
    }
}
