// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import MaternityData

struct KeyValueCardListView: View {
    let title: String
    let state: DataLoadingState
    let dataFetch: () -> Void
    let data: [KeyValueModel]
    
    var body: some View {
        BottomContainerCardView {
            DataLoadingView(state: state, retryAction: dataFetch) {
                ScrollView {
                    JournalKeyValueStackView(title: nil, data: data)
                        .padding(.horizontal)
                        .padding(.bottom)
                    
                }.overlay(GradientTopOverlay())
            }
        }
        .onAppear(perform: dataFetch)
        .navigationBarTitle(Text(title), displayMode: .inline)
        .padding(.top)
    }
}

struct KeyValueCardListView_Previews: PreviewProvider {
    static var previews: some View {
        KeyValueCardListView(
            title: "Hello World",
            state: .data,
            dataFetch: { }, data: [
                KeyValueModel(title: "Test", primaryValue: "Test primary", secondaryValue: nil, dictionaryValue: nil),
                KeyValueModel(title: "Test", primaryValue: "Test primary", secondaryValue: "2020.20.20", dictionaryValue: nil),
                KeyValueModel(title: "Test", primaryValue: "Test primary", secondaryValue: nil, dictionaryValue: "Yes yes")
            ])
    }
}
