// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct ErrorStateView: View {
    let text: String
    let retryAction: () -> Void

    var body: some View {
        VStack {
            Image(R.image.empty_state.name)
            VStack {
                Text(R.string.localizable.common_alert_title_error())
                    .bold()
                    .applyTextStyle(fontStyle: .body)

                Text(text)
                    .applyTextStyle(fontStyle: .body)
            }
            .foregroundColor(R.color.errorRed.color())
            .multilineTextAlignment(.center)

            Button(action: retryAction, label: {
                Text(R.string.localizable.common_cta_retry())
                    .applyTextStyle(fontStyle: .button, textColor: R.color.primary.color())
            })
                .padding(.horizontal, 32)
                .padding(.vertical, 12)
        }
        .padding()
    }
}

struct ErrorView_Previews: PreviewProvider {
    static var previews: some View {
        ErrorStateView(text: "Der er sket en super træls fejl!", retryAction: {
            print("Retry!")
        })
    }
}
