// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import Combine
import ChecklistData
import ErrorData
import HTTPNetworking
import DependencyInjection
import SharedServices

final public class ChecklistServiceImpl: ChecklistService {

    @Inject private var tokenService: TokenService
    @Inject private var networkSession: NetworkSession
    @Inject private var apiConfiguration: ChecklistApiConfiguration

    public init() { }

    public func toggle(checklistId: String, itemId: String, value: Bool) -> AnyPublisher<ChecklistItem, ServiceError> {
        tokenService.accessToken()
            .flatMap { accessToken -> AnyPublisher<ChecklistItem, Error> in
                let request = ToggleChecklistsItemRequest(apiConfiguration: self.apiConfiguration, listId: checklistId, itemId: itemId, value: value, accessToken: accessToken)

                return self.networkSession.dataTaskPublisher(for: request)
                    .map { $0.data }
                    .eraseToAnyPublisher()
            }
            .mapToServiceError()
            .eraseToAnyPublisher()
    }

    public func checklists() -> AnyPublisher<[Checklist], ServiceError> {
        tokenService.accessToken()
            .flatMap { accessToken -> AnyPublisher<[Checklist], Error> in
                let request = ChecklistsRequest(apiConfiguration: self.apiConfiguration, accessToken: accessToken)

                return self.networkSession.dataTaskPublisher(for: request)
                    .map { $0.data }
                    .eraseToAnyPublisher()
            }
            .mapToServiceError()
            .eraseToAnyPublisher()
    }
}
