// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import ChecklistData
import ErrorData
import Combine
import SharedServices

final public class MockChecklistService: ChecklistService {
    private var mockedList: [Checklist] =
        (0..<5).map({ i in
            Checklist(
                id: "ID-\(i)",
                title: "Mock Title \(i)",
                text: (0..<15).map({ _ in "text"}).joined(separator: " ").capitalized,
                items: (0..<10).map({ c in
                    ChecklistItem(
                        id: "ID-\(i)-ITEM-\(c)",
                        title: "Mock Item \(c)",
                        text: (0..<15).map({ _ in "text"}).joined(separator: " ").capitalized,
                        value: false
                    )
                })
            )
        })

    public init() { }

    public func toggle(checklistId: String, itemId: String, value: Bool) -> AnyPublisher<ChecklistItem, ServiceError> {
        guard let listIndex = mockedList.firstIndex(where: { $0.id == checklistId }),
              let itemIndex = mockedList[listIndex].items.firstIndex(where: { $0.id == itemId }) else { return Fail(error: ServiceError.unexpectedError(MockError.randomFail)).eraseToAnyPublisher() }

        let list = mockedList[listIndex]
        let item = list.items[itemIndex]
        let newItem = ChecklistItem(id: item.id, title: item.title, text: item.text, value: !item.value)

        return MockPublisher.mockFailable(
            value: newItem,
            error: ServiceError.unexpectedError(MockError.randomFail)
        )
        .handleEvents(receiveCompletion: { completion in
            switch completion {
            case .failure: break
            case .finished:
                var newItemsList = self.mockedList[listIndex].items
                newItemsList[itemIndex] = newItem

                self.mockedList[listIndex] = Checklist(id: list.id, title: list.title, text: list.title, items: newItemsList)
            }
        })
        .eraseToAnyPublisher()
    }

    public func checklists() -> AnyPublisher<[Checklist], ServiceError> {
        MockPublisher.mockFailable(
            value: self.mockedList,
            error: ServiceError.unexpectedError(MockError.randomFail)
        ).eraseToAnyPublisher()
    }
}
