// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import XCTest
import Combine
import ErrorData
@testable import SharedServices

final class PublishersTests: XCTestCase {

    private var cancelBag = Set<AnyCancellable>()
    
    func testNetworkErrorMapping() {
        assertNSURLError(NSURLErrorTimedOut, expectedNetworkError: .missingInternetConnection)
        assertNSURLError(NSURLErrorNetworkConnectionLost, expectedNetworkError: .missingInternetConnection)
        assertNSURLError(NSURLErrorNotConnectedToInternet, expectedNetworkError: .missingInternetConnection)
        assertNSURLError(NSURLErrorCancelled, expectedNetworkError: .cancelled)

        let otherNsError = NSError(domain: NSURLErrorDomain, code: NSURLErrorBadURL, userInfo: nil)
        assertNSURLError(otherNsError.code, expectedNetworkError: .unexpectedError(otherNsError))
    }


    private func assertNSURLError(_ errorCode: Int, expectedNetworkError: NetworkError) {
        let nsError = NSError(
            domain: NSURLErrorDomain,
            code: errorCode,
            userInfo: nil
        )
        Fail(outputType: Void.self, failure: nsError)
            .mapToServiceError()
            .sink(receiveCompletion: { completion in
                if case .failure(let error) = completion,
                   case ServiceError.networkError(let networkError) = error {
                    XCTAssertEqual(networkError, expectedNetworkError)
                } else {
                    XCTFail("Failed to map \(errorCode) error correctly.")
                }
            }, receiveValue: { _ in })
            .store(in: &cancelBag)
    }

    static var allTests = [
        ("testNetworkErrorMapping", testNetworkErrorMapping),
    ]
}
